==> SpeCond_1.4.0.zip: SpeCond/doc/SpeCond.R <==
###################################################
### chunk number 1: 
###################################################
#line 54 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
d=tempdir()
oldir=getwd()
setwd(d)


###################################################
### chunk number 2: 
###################################################
#line 60 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
library(SpeCond)
data(expSetSpeCondExample)
expSetSpeCondExample
class(expSetSpeCondExample)
data(expressionSpeCondExample)
Mexp=expressionSpeCondExample
class(Mexp)
dim(Mexp)


###################################################
### chunk number 3: 
###################################################
#line 72 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
generalResult=SpeCond(Mexp, param.detection=NULL, multitest.correction.method="BY",
  prefix.file="E", print.hist.pv=TRUE, fit1=NULL, fit2=NULL, specificOutlierStep1=NULL)
names(generalResult)
specificResult=generalResult$specificResult


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 80 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
## generalResult=SpeCond(expSetSpeCondExample, param.detection=NULL, 
##   multitest.correction.method="BY", prefix.file="E", print.hist.pv=TRUE, fit1=NULL,
##   fit2=NULL, specificOutlierStep1=NULL, condition.factor=expSetSpeCondExample$Tissue,
##   condition.method="mean")


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 87 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
## MexpS=getMatrixFromExpressionSet(expSetSpeCondExample,
##   condition.factor=expSetSpeCondExample$Tissue,condition.method="mean")


###################################################
### chunk number 6: 
###################################################
#line 105 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
getFullHtmlSpeCondResult(SpeCondResult=generalResult, param.detection=
  specificResult$param.detection, page.name="Example_SpeCond_results",
  page.title="Tissue specific results", sort.condition="all", heatmap.profile=TRUE,
  heatmap.expression=FALSE, heatmap.unique.profile=FALSE, expressionMatrix=Mexp)


###################################################
### chunk number 7: 
###################################################
#line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
genePageInfo=getGeneHtmlPage(Mexp, specificResult, name.index.html=
  "index_example_SpeCond_Results.html", gene.html.ids=c(1:20))


###################################################
### chunk number 8: 
###################################################
#line 158 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
param.detection=getDefaultParameter()
param.detection


###################################################
### chunk number 9: 
###################################################
#line 163 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
param.detection2=createParameterMatrix(mlk.1=10)
param.detection2
param.detection2B=createParameterMatrix(param.detection=param.detection2, 
  mlk.1=15, rsd.2=0.2)
param.detection2B


###################################################
### chunk number 10: 
###################################################
#line 190 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
param.detection2=createParameterMatrix(param.detection, mlk.1=10)
param.detection2
generalResult2=SpeCond(Mexp, param.detection=param.detection2,
  multitest.correction.method="BY", prefix.file="E2", 
  print.hist.pv=TRUE, fit1=generalResult$fit1, fit2=NULL, 
  specificOutlierStep1=NULL)


###################################################
### chunk number 11: 
###################################################
#line 199 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
param.detection3=createParameterMatrix(param.detection, rsd.2=0.2, per.2=0.2)
param.detection3
generalResult3=SpeCond(Mexp, param.detection=param.detection3,
  multitest.correction.method="BY", prefix.file="E3", print.hist.pv=TRUE,
  fit1=generalResult$fit1, fit2=generalResult$fit2,
  specificOutlierStep1=generalResult$specificOutliersStep1)


###################################################
### chunk number 12: 
###################################################
#line 220 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
param.detection
fit1=fitPrior(Mexp, param.detection=param.detection)


###################################################
### chunk number 13:  eval=FALSE
###################################################
## #line 225 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
## fit1=fitPrior(Mexp, lambda=param.detection[1,"lambda"], beta=param.detection[1,"beta"])


###################################################
### chunk number 14: 
###################################################
#line 229 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
specificOutlierStep1=getSpecificOutliersStep1(Mexp, fit=fit1$fit1,param.detection,
  multitest.correction.method="BY", prefix.file="run1_Step1",
  print.hist.pv=FALSE)


###################################################
### chunk number 15: 
###################################################
#line 235 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
fit2=fitNoPriorWithExclusion(Mexp, specificOutlierStep1=specificOutlierStep1,
  param.detection=param.detection)


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 240 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
## fit2=fitNoPriorWithExclusion(Mexp, specificOutlierStep1=specificOutlierStep1, 
##   lambda=param.detection[2,"lambda"], beta=param.detection[2,"beta"])


###################################################
### chunk number 17: 
###################################################
#line 245 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
specificResult=getSpecificResult(Mexp, fit=fit2,
  specificOutlierStep1=specificOutlierStep1, param.detection, 
  multitest.correction.method="BY", prefix.file="run1_Step2",
  print.hist.pv=FALSE)


###################################################
### chunk number 18: 
###################################################
#line 298 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
names(generalResult)
specificResult=generalResult$specificResult
names(specificResult)
names(specificResult$L.specific.result)
dim(specificResult$L.specific.result$M.specific.all)
dim(specificResult$L.specific.result$M.specific)
specificResult


###################################################
### chunk number 19: 
###################################################
#line 322 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
L.specific.result.profile=getProfile(specificResult$L.specific.result$M.specific)
writeSpeCondResult(specificResult$L.specific.result,file.name.profile=
  "Example_specific_profile.txt", file.specific.gene="Example_list_specific_gene.txt",
  file.name.unique.profile="Example_specific_unique_profile.txt")
writeUniqueProfileSpecificResult(L.specific.result=specificResult$L.specific.result,
  file.name.unique.profile="Example_specific_unique_profile.txt", full.list.gene=FALSE)
writeGeneResult(specificResult$L.specific.result, file.name.result.gene=
  "Example_gene_gummary_result.txt", gene.names=rownames(Mexp)[1:10])


###################################################
### chunk number 20: 
###################################################
#line 370 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
data(simulatedSpeCondData)


###################################################
### chunk number 21: 
###################################################
#line 374 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
generalResult_S1=SpeCond(simulatedSpeCondData, param.detection=NULL,
  multitest.correction.method="BY", prefix.file="S1", print.hist.pv=TRUE,
  fit1=NULL, fit2=NULL, specificOutlierStep1=NULL)

specificResult_S1=generalResult_S1$specificResult
getFullHtmlSpeCondResult(L.specific.result=specificResult_S1$L.specific.result,
  page.name="simulatedSpeCondData_results", page.title="Condition specific results mlk 25 
  default", prefix.file="S1", sort.condition="all")
genePageInfo_S1=getGeneHtmlPage(simulatedSpeCondData, specificResult_S1,
  name.index.html="index_simulatedSpeCondData.html", prefix.file="S1",
  gene.html.ids=c(1:20))


###################################################
### chunk number 22: 
###################################################
#line 391 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
param.detection10=createParameterMatrix(param.detection=param.detection, mlk.2=10)
param.detection10


###################################################
### chunk number 23: 
###################################################
#line 396 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
generalResult_S2=SpeCond(simulatedSpeCondData, param.detection=param.detection10,
  multitest.correction.method="BY", prefix.file="S2", print.hist.pv=TRUE,
  fit1=generalResult_S1$fit1, fit2=generalResult_S1$fit2, 
  specificOutlierStep1=generalResult_S1$specificOutliersStep1)

specificResult_S2=generalResult_S2$specificResult

genePageInfo_S2=getGeneHtmlPage(simulatedSpeCondData, specificResult_S2, 
  name.index.html="index_simulatedSpeCondData.html", prefix.file="S2", 
  gene.html.ids=c(1:20,200:250))

getFullHtmlSpeCondResult(L.specific.result=specificResult_S2$L.specific.result,
  param.detection=param.detection10, page.name="simulatedSpeCondData_results", 
  page.title="Condition specific results mlk 10",prefix.file="S2", sort.condition="all",
  gene.page.info=genePageInfo_S2)


###################################################
### chunk number 24: 
###################################################
#line 416 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
param.detection8_0.3=createParameterMatrix(param.detection=param.detection, 
  mlk.2=8, rsd.2=0.3)
param.detection8_0.3


###################################################
### chunk number 25: 
###################################################
#line 422 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
generalResult_S3=SpeCond(simulatedSpeCondData, param.detection=param.detection8_0.3,
  multitest.correction.method="BY", prefix.file="S3", print.hist.pv=TRUE, 
  fit1=generalResult_S1$fit1, fit2=generalResult_S1$fit2,
  specificOutlierStep1=generalResult_S1$specificOutliersStep1)
specificResult_S3=generalResult_S3$specificResult
genePageInfo_S3=getGeneHtmlPage(simulatedSpeCondData, specificResult_S3,
  name.index.html="index_simulatedSpeCondData.html", prefix.file="S3", 
  gene.html.ids=c(1:20,195:310))

getFullHtmlSpeCondResult(L.specific.result=specificResult_S3$L.specific.result,
  param.detection=param.detection8_0.3, page.name="simulatedSpeCondData_results", 
  page.title="Condition specific results mlk 8, rsd 0.3", prefix.file="S3", 
  sort.condition="all",gene.page.info=genePageInfo_S3)


###################################################
### chunk number 26: 
###################################################
#line 437 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
setwd(oldir)


###################################################
### chunk number 27: 
###################################################
#line 445 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
save(fit1,file="fit1.RData")
## load("fit1.RData")


###################################################
### chunk number 28: 
###################################################
#line 450 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
save(specificOutlierStep1,file="specificOutlierStep1.RData")
## load("specificStep1.RData")
save(fit2,file="fit2.RData")
## load("fit2.Rdata")
save(specificResult,file="specificResult.RData")


###################################################
### chunk number 29: pkgs
###################################################
#line 458 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmppd8PIe/R.INSTALL6e3a44a/SpeCond/inst/doc/SpeCond.Rnw"
toLatex(sessionInfo())

==> SpeCond_1.6.0.zip: SpeCond/doc/SpeCond.R <==
###################################################
### chunk number 1: 
###################################################
#line 54 "SpeCond.Rnw"
d=tempdir()
oldir=getwd()
setwd(d)


###################################################
### chunk number 2: 
###################################################
#line 60 "SpeCond.Rnw"
library(SpeCond)
data(expSetSpeCondExample)
expSetSpeCondExample
class(expSetSpeCondExample)
data(expressionSpeCondExample)
Mexp=expressionSpeCondExample
class(Mexp)
dim(Mexp)


###################################################
### chunk number 3: 
###################################################
#line 72 "SpeCond.Rnw"
generalResult=SpeCond(Mexp, param.detection=NULL, multitest.correction.method="BY",
  prefix.file="E", print.hist.pv=TRUE, fit1=NULL, fit2=NULL, specificOutlierStep1=NULL)
names(generalResult)
specificResult=generalResult$specificResult


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 80 "SpeCond.Rnw"
## generalResult=SpeCond(expSetSpeCondExample, param.detection=NULL, 
##   multitest.correction.method="BY", prefix.file="E", print.hist.pv=TRUE, fit1=NULL,
##   fit2=NULL, specificOutlierStep1=NULL, condition.factor=expSetSpeCondExample$Tissue,
##   condition.method="mean")


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 87 "SpeCond.Rnw"
## MexpS=getMatrixFromExpressionSet(expSetSpeCondExample,
##   condition.factor=expSetSpeCondExample$Tissue,condition.method="mean")


###################################################
### chunk number 6: 
###################################################
#line 105 "SpeCond.Rnw"
getFullHtmlSpeCondResult(SpeCondResult=generalResult, param.detection=
  specificResult$param.detection, page.name="Example_SpeCond_results",
  page.title="Tissue specific results", sort.condition="all", heatmap.profile=TRUE,
  heatmap.expression=FALSE, heatmap.unique.profile=FALSE, expressionMatrix=Mexp)


###################################################
### chunk number 7: 
###################################################
#line 126 "SpeCond.Rnw"
genePageInfo=getGeneHtmlPage(Mexp, specificResult, name.index.html=
  "index_example_SpeCond_Results.html", gene.html.ids=c(1:20))


###################################################
### chunk number 8: 
###################################################
#line 158 "SpeCond.Rnw"
param.detection=getDefaultParameter()
param.detection


###################################################
### chunk number 9: 
###################################################
#line 163 "SpeCond.Rnw"
param.detection2=createParameterMatrix(mlk.1=10)
param.detection2
param.detection2B=createParameterMatrix(param.detection=param.detection2, 
  mlk.1=15, rsd.2=0.2)
param.detection2B


###################################################
### chunk number 10: 
###################################################
#line 190 "SpeCond.Rnw"
param.detection2=createParameterMatrix(param.detection, mlk.1=10)
param.detection2
generalResult2=SpeCond(Mexp, param.detection=param.detection2,
  multitest.correction.method="BY", prefix.file="E2", 
  print.hist.pv=TRUE, fit1=generalResult$fit1, fit2=NULL, 
  specificOutlierStep1=NULL)


###################################################
### chunk number 11: 
###################################################
#line 199 "SpeCond.Rnw"
param.detection3=createParameterMatrix(param.detection, rsd.2=0.2, per.2=0.2)
param.detection3
generalResult3=SpeCond(Mexp, param.detection=param.detection3,
  multitest.correction.method="BY", prefix.file="E3", print.hist.pv=TRUE,
  fit1=generalResult$fit1, fit2=generalResult$fit2,
  specificOutlierStep1=generalResult$specificOutliersStep1)


###################################################
### chunk number 12: 
###################################################
#line 220 "SpeCond.Rnw"
param.detection
fit1=fitPrior(Mexp, param.detection=param.detection)


###################################################
### chunk number 13:  eval=FALSE
###################################################
## #line 225 "SpeCond.Rnw"
## fit1=fitPrior(Mexp, lambda=param.detection[1,"lambda"], beta=param.detection[1,"beta"])


###################################################
### chunk number 14: 
###################################################
#line 229 "SpeCond.Rnw"
specificOutlierStep1=getSpecificOutliersStep1(Mexp, fit=fit1$fit1,param.detection,
  multitest.correction.method="BY", prefix.file="run1_Step1",
  print.hist.pv=FALSE)


###################################################
### chunk number 15: 
###################################################
#line 235 "SpeCond.Rnw"
fit2=fitNoPriorWithExclusion(Mexp, specificOutlierStep1=specificOutlierStep1,
  param.detection=param.detection)


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 240 "SpeCond.Rnw"
## fit2=fitNoPriorWithExclusion(Mexp, specificOutlierStep1=specificOutlierStep1, 
##   lambda=param.detection[2,"lambda"], beta=param.detection[2,"beta"])


###################################################
### chunk number 17: 
###################################################
#line 245 "SpeCond.Rnw"
specificResult=getSpecificResult(Mexp, fit=fit2,
  specificOutlierStep1=specificOutlierStep1, param.detection, 
  multitest.correction.method="BY", prefix.file="run1_Step2",
  print.hist.pv=FALSE)


###################################################
### chunk number 18: 
###################################################
#line 298 "SpeCond.Rnw"
names(generalResult)
specificResult=generalResult$specificResult
names(specificResult)
names(specificResult$L.specific.result)
dim(specificResult$L.specific.result$M.specific.all)
dim(specificResult$L.specific.result$M.specific)
specificResult


###################################################
### chunk number 19: 
###################################################
#line 322 "SpeCond.Rnw"
L.specific.result.profile=getProfile(specificResult$L.specific.result$M.specific)
writeSpeCondResult(specificResult$L.specific.result,file.name.profile=
  "Example_specific_profile.txt", file.specific.gene="Example_list_specific_gene.txt",
  file.name.unique.profile="Example_specific_unique_profile.txt")
writeUniqueProfileSpecificResult(L.specific.result=specificResult$L.specific.result,
  file.name.unique.profile="Example_specific_unique_profile.txt", full.list.gene=FALSE)
writeGeneResult(specificResult$L.specific.result, file.name.result.gene=
  "Example_gene_gummary_result.txt", gene.names=rownames(Mexp)[1:10])


###################################################
### chunk number 20: 
###################################################
#line 370 "SpeCond.Rnw"
data(simulatedSpeCondData)


###################################################
### chunk number 21: 
###################################################
#line 374 "SpeCond.Rnw"
generalResult_S1=SpeCond(simulatedSpeCondData, param.detection=NULL,
  multitest.correction.method="BY", prefix.file="S1", print.hist.pv=TRUE,
  fit1=NULL, fit2=NULL, specificOutlierStep1=NULL)

specificResult_S1=generalResult_S1$specificResult
getFullHtmlSpeCondResult(L.specific.result=specificResult_S1$L.specific.result,
  page.name="simulatedSpeCondData_results", page.title="Condition specific results mlk 25 
  default", prefix.file="S1", sort.condition="all")
genePageInfo_S1=getGeneHtmlPage(simulatedSpeCondData, specificResult_S1,
  name.index.html="index_simulatedSpeCondData.html", prefix.file="S1",
  gene.html.ids=c(1:20))


###################################################
### chunk number 22: 
###################################################
#line 391 "SpeCond.Rnw"
param.detection10=createParameterMatrix(param.detection=param.detection, mlk.2=10)
param.detection10


###################################################
### chunk number 23: 
###################################################
#line 396 "SpeCond.Rnw"
generalResult_S2=SpeCond(simulatedSpeCondData, param.detection=param.detection10,
  multitest.correction.method="BY", prefix.file="S2", print.hist.pv=TRUE,
  fit1=generalResult_S1$fit1, fit2=generalResult_S1$fit2, 
  specificOutlierStep1=generalResult_S1$specificOutliersStep1)

specificResult_S2=generalResult_S2$specificResult

genePageInfo_S2=getGeneHtmlPage(simulatedSpeCondData, specificResult_S2, 
  name.index.html="index_simulatedSpeCondData.html", prefix.file="S2", 
  gene.html.ids=c(1:20,200:250))

getFullHtmlSpeCondResult(L.specific.result=specificResult_S2$L.specific.result,
  param.detection=param.detection10, page.name="simulatedSpeCondData_results", 
  page.title="Condition specific results mlk 10",prefix.file="S2", sort.condition="all",
  gene.page.info=genePageInfo_S2)


###################################################
### chunk number 24: 
###################################################
#line 416 "SpeCond.Rnw"
param.detection8_0.3=createParameterMatrix(param.detection=param.detection, 
  mlk.2=8, rsd.2=0.3)
param.detection8_0.3


###################################################
### chunk number 25: 
###################################################
#line 422 "SpeCond.Rnw"
generalResult_S3=SpeCond(simulatedSpeCondData, param.detection=param.detection8_0.3,
  multitest.correction.method="BY", prefix.file="S3", print.hist.pv=TRUE, 
  fit1=generalResult_S1$fit1, fit2=generalResult_S1$fit2,
  specificOutlierStep1=generalResult_S1$specificOutliersStep1)
specificResult_S3=generalResult_S3$specificResult
genePageInfo_S3=getGeneHtmlPage(simulatedSpeCondData, specificResult_S3,
  name.index.html="index_simulatedSpeCondData.html", prefix.file="S3", 
  gene.html.ids=c(1:20,195:310))

getFullHtmlSpeCondResult(L.specific.result=specificResult_S3$L.specific.result,
  param.detection=param.detection8_0.3, page.name="simulatedSpeCondData_results", 
  page.title="Condition specific results mlk 8, rsd 0.3", prefix.file="S3", 
  sort.condition="all",gene.page.info=genePageInfo_S3)


###################################################
### chunk number 26: 
###################################################
#line 437 "SpeCond.Rnw"
setwd(oldir)


###################################################
### chunk number 27: 
###################################################
#line 445 "SpeCond.Rnw"
save(fit1,file="fit1.RData")
## load("fit1.RData")


###################################################
### chunk number 28: 
###################################################
#line 450 "SpeCond.Rnw"
save(specificOutlierStep1,file="specificOutlierStep1.RData")
## load("specificStep1.RData")
save(fit2,file="fit2.RData")
## load("fit2.Rdata")
save(specificResult,file="specificResult.RData")


###################################################
### chunk number 29: pkgs
###################################################
#line 458 "SpeCond.Rnw"
toLatex(sessionInfo())
